Plot median +- IQR of Tsallis entropy across q values by group
Source:R/generate_plots.R
plot_tsallis_q_curve.RdThis reproduces the `tsallis-q-curve-mean-sd` plot from the vignette: for each q value, compute per-gene Tsallis entropy per sample, summarize across genes by group (median and IQR) and plot median with a ribbon spanning median +- IQR/2.
Examples
data("tcga_brca_luma", package = "TSENAT")
rc <- as.matrix(tcga_brca_luma[1:40, -1, drop = FALSE])
gs <- tcga_brca_luma[1:40, 1]
se <- calculate_diversity(rc, gs,
q = seq(0.01, 0.1, by = 0.03), norm = FALSE
)
p <- plot_tsallis_q_curve(se)
p